spacepy.data_assimilation.ensemble — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »

# spacepy.data_assimilation.ensemble

class `spacepy.data_assimilation.` `ensemble`(ensembles=50)

  Ensemble-based data assimilation subroutines for the Radiation Belt Model

  `EnKF`(A, Psi, Inn, HAp) | analysis subroutine after code example in
  `EnKF_oneobs`(A, Psi, Inn, HAp) | analysis subroutine for a single observations
  `add_model_error`(model, A, PSDdata) | this routine will add a standard error to the ensemble states
  `add_model_error_obs`(model, A, Lobs, y) | this routine will add a standard error to the ensemble states
  `getHA`(model, Lobs, A) | compute HA provided L vector of observations
  `getHAprime`(HA) | calculate ensemble perturbation of HA
  `getHPH`(Lobs, Pfxx) | compute HPH
  `getInnovation`(y, Psi, HA) | compute innovation ensemble D’
  `getperturb`(model, y) | compute perturbations of observational vector

  `EnKF`(A, Psi, Inn, HAp)

    analysis subroutine after code example in Evensen 2003 this will take the prepared matrices and calculate the analysis most efficiently, A will be returned

    Parameters: | A : : Psi : : Inn : : HAp : :
    Returns: | out : :

  `EnKF_oneobs`(A, Psi, Inn, HAp)

    analysis subroutine for a single observations with the EnKF. This is a special case.

    Parameters: | A : : Psi : : Inn : : HAp : :
    Returns: | out : :

  `add_model_error`(model, A, PSDdata)

    this routine will add a standard error to the ensemble states

    Parameters: | model : : A : : PSDdata : :
    Returns: | out : :

  `add_model_error_obs`(model, A, Lobs, y)

    this routine will add a standard error to the ensemble states

    Parameters: | model : : A : : Lobs : : y : :
    Returns: | out : :

  `getHA`(model, Lobs, A)

    compute HA provided L vector of observations and ensemble matrix A

    Parameters: | model : : Lobs : : A : :
    Returns: | out : :

  `getHAprime`(HA)

    calculate ensemble perturbation of HA HA’ = HA-HA_mean

    Parameters: | HA : :
    Returns: | out : :

  `getHPH`(Lobs, Pfxx)

    compute HPH

    Parameters: | Lobs : Pfxx :
    Returns: | out :

  `getInnovation`(y, Psi, HA)

    compute innovation ensemble D’

    Parameters: | y : : Psi : : HA : :
    Returns: | out : :

  `getperturb`(model, y)

    compute perturbations of observational vector

    Parameters: | model : : y : :
    Returns: | out : :

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »